pub struct DocFragmentEntry {
pub id: &'static str,
pub seq: u32,
pub frag: DocFragment,
}Expand description
One annotation: the endpoint id plus the annotated piece of documentation.
seq is assigned by the macro at expansion time (source order) and is used
by DocRegistry::collect to restore declaration order, since linkme’s
linker-section iteration order is not source order.
Fields
id: &'static strseq: u32frag: DocFragmentAuto Trait Implementations
impl Freeze for DocFragmentEntry
impl RefUnwindSafe for DocFragmentEntry
impl Send for DocFragmentEntry
impl Sync for DocFragmentEntry
impl Unpin for DocFragmentEntry
impl UnsafeUnpin for DocFragmentEntry
impl UnwindSafe for DocFragmentEntry